@@ -12,7 +12,7 @@
 #'        This can be a character string naming a family function, a family function or the result
 #'        of a call to a family function. (See \code{\link{family}} for details of family functions.)
 #' @param control options for the optimization procedure (see \code{\link{optim}},
-#'        \code{\link{ucminf}} for options and details).
+#'        \code{\link[ucminf]{ucminf}} for options and details).
 #' @param par (optional) starting parameter vector
 #' @param setM (optional) matrix, rows containing potential patterns for a misclassified (latent) covariate M
 #'        in any coding for a categorical independent variable, e.g. dummy coding (default: Identity).
@@ -241,7 +241,7 @@ boot.misclassGLM <- function(ret, Y, X, Pmodel, PX,
   if (boot.fraction > 1) stop("boot.fraction must be <1")
   if (boot.fraction <= 0) stop("boot.fraction must be >0")
 
-  if (!is.matrix(X) & (!is.big.matrix(X))) stop("X is no matrix")
+  if (!is.matrix(X)) stop("X is no matrix")
   if (!is.vector(Y)) stop("Y must be a vector")
   if (length(Y) != nrow(X)) stop("dimensions of Y and X do not match")
 
